
/*
 * -----------------------------------------------------------------------------
 * File  Name     : AesoppreparationDAO.java
 * Description    : DAO class
 * Special Logics :
 * @author        : Suh Hyuck Jun
 * @version       : 1.0
 * @Date          : 2005.12.24
 *------------------------------------------------------------------------------
 * History :
 *  DATE              AUTHOR          DESCRIPTION
 * -----------      -------------    -------------------
 *  2005.12.24      Suh, Hyuck Jun    Initial Release
 *------------------------------------------------------------------------------
 * Copyright(c) 2004,  All rights reserved.
 *
 * NOTICE !    You can not copy or redistribute this code.
 *
 */
package cc.struts.cian3.aesoppreparation.dao;

import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.Connection;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.Collection;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import cc.struts.cian3.dao.LoggableStatement;
import cc.struts.cian3.dao.SuperDAO;
import cc.struts.cian3.exception.DatabaseException;
import cc.struts.cian3.aesoppreparation.dto.AesoppreparationDTO;
import cc.struts.cian3.aesoppreparationlist.dto.AesoppreparationlistDTO;


public class AesoppreparationDAO extends SuperDAO {
    static private final Log log = LogFactory.getLog(AesoppreparationDAO.class);



    public int insertAesoppreparation( AesoppreparationDTO aesoppreparation ) throws DatabaseException {
        StringBuffer query = new StringBuffer();
        query.append( "INSERT INTO TB_PREPARATION(                              \n" );
        query.append( "                      c_user_eid                         \n" );
        query.append( "                     ,c_overview_eid                     \n" );
        query.append( "                     ,c_document_eid                     \n" );
        query.append( "                     ,c_preparation_eid                  \n" );
        query.append( "                     ,c_consumed_time                    \n" );
        query.append( "              )VALUES(                                   \n" );
        query.append( "                      ?                                  \n" );
        query.append( "                     ,?                                  \n" );
        query.append( "                     ,?                                  \n" );
        query.append( "                     ,?                                  \n" );
        query.append( "                     ,?                                  \n" );
        query.append( "              )                                          \n" );

        PreparedStatement pstmt = null;
        int count = 0;
        Connection conn = null;
        conn = getConnection();
        try {
            if(logEnabled) pstmt = new LoggableStatement(conn,query.toString());
            else pstmt = conn.prepareStatement(query.toString());

            pstmt.setInt   ( 1, aesoppreparation.getUser_eid() );
            pstmt.setInt   ( 2, aesoppreparation.getOverview_eid() );
            pstmt.setInt   ( 3, aesoppreparation.getDocument_eid() );
            pstmt.setInt   ( 4, aesoppreparation.getPreparation_eid() );
            pstmt.setInt   ( 5, aesoppreparation.getConsumed_time() );

            if(logEnabled) log.warn(((LoggableStatement)pstmt).getQueryString());
            else log.warn( query.toString() );

            count = pstmt.executeUpdate();

            conn.commit();
        }
        catch (Exception e) {
            e.printStackTrace();
            try{ conn.rollback(); }catch(SQLException sqlex){sqlex.printStackTrace();}
            throw new DatabaseException();
        }
        finally {
            try {closeConnection( conn );} catch (Exception e) { /*do nothing*/}
        }
        return count;

    }

    public int selectSeq( AesoppreparationDTO aesoppreparation ) throws DatabaseException {
        int count = 0;
        StringBuffer query = new StringBuffer();
        query.append( "SELECT MAX(c_preparation_eid) + 1 eid               \n" );
        query.append( "  FROM TB_PREPARATION                               \n" );
        query.append( " WHERE c_document_eid = ?                           \n" );
        query.append( "   AND c_overview_eid  = ?                          \n" );
        query.append( "   AND c_user_eid = ?                               \n" );

        PreparedStatement pstmt = null;
        ResultSet rs = null;
        Connection conn = null;
        conn = getConnection();

        try {
            if(logEnabled) pstmt = new LoggableStatement(conn,query.toString());
            else pstmt = conn.prepareStatement(query.toString());
          
            pstmt.setInt( 1, aesoppreparation.getDocument_eid() );
            pstmt.setInt( 2, aesoppreparation.getOverview_eid() );
            pstmt.setInt( 3, aesoppreparation.getUser_eid() );
          
            if(logEnabled) log.warn(((LoggableStatement)pstmt).getQueryString());
            else log.warn( query.toString() );

            rs = pstmt.executeQuery();

            if (rs.next()) {
              count= rs.getInt("eid");
            }
        }
        catch (Exception e) {
            e.printStackTrace();
            throw new DatabaseException();
        }
        finally {
            try {closeConnection( conn );} catch (Exception e) { /*do nothing*/}
        }

        return count;

    }


    public AesoppreparationDTO[] selectAesoppreparationList( AesoppreparationDTO aesoppreparation ) throws DatabaseException {
        AesoppreparationDTO[] arrDto = null;
        ArrayList list = new ArrayList();

        StringBuffer query = new StringBuffer();
        query.append( "SELECT                                                   \n" );
        query.append( "        c_user_eid                                       \n" );
        query.append( "       ,c_overview_eid                                   \n" );
        query.append( "       ,c_document_eid                                   \n" );
        query.append( "       ,c_preparation_eid                                \n" );
        query.append( "       ,c_consumed_time                                  \n" );
        query.append( "  FROM TB_PREPARATION                                    \n" );

        PreparedStatement pstmt = null;
        ResultSet rs = null;
        Connection conn = null;
        conn = getConnection();

        try {
            if(logEnabled) pstmt = new LoggableStatement(conn,query.toString());
            else pstmt = conn.prepareStatement(query.toString());

            if(logEnabled) log.warn(((LoggableStatement)pstmt).getQueryString());
            else log.warn( query.toString() );

            rs = pstmt.executeQuery();

            while ( rs.next() ){
                AesoppreparationDTO dto = new AesoppreparationDTO();
                dto.setUser_eid( rs.getInt( "c_user_eid" ) );
                dto.setOverview_eid( rs.getInt( "c_overview_eid" ) );
                dto.setDocument_eid( rs.getInt( "c_document_eid" ) );
                dto.setPreparation_eid( rs.getInt( "c_preparation_eid" ) );
                dto.setConsumed_time( rs.getInt( "c_consumed_time" ) );

                list.add(dto);
            }
        }
        catch (Exception e) {
            e.printStackTrace();
            throw new DatabaseException();
        }
        finally {
            try {closeConnection( conn );} catch (Exception e) { /*do nothing*/}
        }

        arrDto = new AesoppreparationDTO[list.size()];
        list.toArray( arrDto );
        return arrDto;

    }

    public AesoppreparationDTO selectAesoppreparation( AesoppreparationDTO aesoppreparation ) throws DatabaseException {
        AesoppreparationDTO dto = new AesoppreparationDTO();

        StringBuffer query = new StringBuffer();
        query.append( "SELECT                                                   \n" );
        query.append( "        c_user_eid                                       \n" );
        query.append( "       ,c_overview_eid                                   \n" );
        query.append( "       ,c_document_eid                                   \n" );
        query.append( "       ,c_preparation_eid                                \n" );
        query.append( "       ,c_consumed_time                                  \n" );
        query.append( "  FROM TB_PREPARATION                                    \n" );
        query.append( " WHERE c_user_eid = ?                                    \n" );
        query.append( "   AND c_document_eid = ?                                \n" );
        query.append( "   AND c_overview_eid = ?                                \n" );
        query.append( "   AND c_preparation_eid = ?                             \n" );

        PreparedStatement pstmt = null;
        ResultSet rs = null;
        Connection conn = null;
        conn = getConnection();

        try {
            if(logEnabled) pstmt = new LoggableStatement(conn,query.toString());
            else pstmt = conn.prepareStatement(query.toString());

            pstmt.setInt( 1, aesoppreparation.getUser_eid() );
            pstmt.setInt( 2, aesoppreparation.getDocument_eid() ); 
            pstmt.setInt( 3, aesoppreparation.getOverview_eid() ); 
            pstmt.setInt( 4, aesoppreparation.getPreparation_eid() ); 

            if(logEnabled) log.warn(((LoggableStatement)pstmt).getQueryString());
            else log.warn( query.toString() );

            rs = pstmt.executeQuery();

            if (rs.next()) {
                dto.setUser_eid( rs.getInt( "c_user_eid" ) );
                dto.setOverview_eid( rs.getInt( "c_overview_eid" ) );
                dto.setDocument_eid( rs.getInt( "c_document_eid" ) );
                dto.setPreparation_eid( rs.getInt( "c_preparation_eid" ) );
                dto.setConsumed_time( rs.getInt( "c_consumed_time" ) );
            }
        }
        catch (Exception e) {
            e.printStackTrace();
            throw new DatabaseException();
        }
        finally {
            try {closeConnection( conn );} catch (Exception e) { /*do nothing*/}
        }

        return dto;

    }



    public int updateAesoppreparation( AesoppreparationDTO aesoppreparation ) throws DatabaseException {
        StringBuffer query = new StringBuffer();
        query.append( "UPDATE TB_PREPARATION                                    \n" );
        query.append( "   SET c_consumed_time = ?                               \n" );
        query.append( " WHERE c_user_eid = ?                                    \n" );
        query.append( "   AND c_document_eid = ?                                \n" );
        query.append( "   AND c_overview_eid = ?                                \n" );
        query.append( "   AND c_preparation_eid = ?                             \n" );
        

        PreparedStatement pstmt = null;
        int count = 0;
        Connection conn = null;
        conn = getConnection();

        try {
            if(logEnabled) pstmt = new LoggableStatement(conn,query.toString());
            else pstmt = conn.prepareStatement(query.toString());

            pstmt.setInt   ( 1, aesoppreparation.getConsumed_time() );
            pstmt.setInt   ( 2, aesoppreparation.getUser_eid() ); 
            pstmt.setInt   ( 3, aesoppreparation.getDocument_eid() );
            pstmt.setInt   ( 4, aesoppreparation.getOverview_eid() );
            pstmt.setInt   ( 5, aesoppreparation.getPreparation_eid() );
            
            
            if(logEnabled) log.warn(((LoggableStatement)pstmt).getQueryString());
            else log.warn( query.toString() );

            count = pstmt.executeUpdate();

            conn.commit();
        }
        catch (Exception e) {
            e.printStackTrace();
            try{ conn.rollback(); }catch(SQLException sqlex){sqlex.printStackTrace();}
            throw new DatabaseException();
        }
        finally {
            try {closeConnection( conn );} catch (Exception e) { /*do nothing*/}
        }
        return count;

    }


    public int deleteAesoppreparation( AesoppreparationDTO aesoppreparation ) throws DatabaseException {
        StringBuffer query = new StringBuffer();
        query.append( "UPDATE TB_PREPARATION                                    \n" );
        query.append( "   SET c_del_yn = 'Y'                                    \n" );
        query.append( " WHERE c_document_eid = ?                                \n" );
        query.append( "   AND c_overview_eid = ?                                \n" );
        query.append( "   AND c_user_eid = ?                                    \n" );
        query.append( "   AND c_preparation_eid = ?                             \n" );
     
        PreparedStatement pstmt = null;
        int count = 0;
        Connection conn = null;
        conn = getConnection();

        try {
            if(logEnabled) pstmt = new LoggableStatement(conn,query.toString());
            else pstmt = conn.prepareStatement(query.toString());

            pstmt.setInt( 1, aesoppreparation.getDocument_eid() );
            pstmt.setInt( 2, aesoppreparation.getOverview_eid() );
            pstmt.setInt( 3, aesoppreparation.getUser_eid() );
            pstmt.setInt( 4, aesoppreparation.getPreparation_eid() );
        
            if(logEnabled) log.warn(((LoggableStatement)pstmt).getQueryString());
            else log.warn( query.toString() );

            count = pstmt.executeUpdate();

            conn.commit();
        }
        catch (Exception e) {
            e.printStackTrace();
            try{ conn.rollback(); }catch(SQLException sqlex){sqlex.printStackTrace();}
            throw new DatabaseException();
        }
        finally {
            try {closeConnection( conn );} catch (Exception e) { /*do nothing*/}
        }
        return count;

    }

}
