
/*
 * -----------------------------------------------------------------------------
 * File  Name     : AesoppreparationlistDAO.java
 * Description    : DAO class
 * Special Logics :
 * @author        : Suh Hyuck Jun
 * @version       : 1.0
 * @Date          : 2005.12.24
 *------------------------------------------------------------------------------
 * History :
 *  DATE              AUTHOR          DESCRIPTION
 * -----------      -------------    -------------------
 *  2005.12.24      Suh, Hyuck Jun    Initial Release
 *------------------------------------------------------------------------------
 * Copyright(c) 2004,  All rights reserved.
 *
 * NOTICE !    You can not copy or redistribute this code.
 *
 */
package cc.struts.cian3.aesoppreparationlist.dao;

import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.Connection;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.Collection;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import cc.struts.cian3.dao.LoggableStatement;
import cc.struts.cian3.dao.SuperDAO;
import cc.struts.cian3.exception.DatabaseException;
import cc.struts.cian3.aesoppreparationlist.dto.AesoppreparationlistDTO;


public class AesoppreparationlistDAO extends SuperDAO {
    static private final Log log = LogFactory.getLog(AesoppreparationlistDAO.class);



    public int insertAesoppreparationlist( AesoppreparationlistDTO aesoppreparationlist ) throws DatabaseException {
        StringBuffer query = new StringBuffer();
        query.append( "INSERT INTO TB_PREPARATIONLIST(                          \n" );
        query.append( "                      c_user_eid                         \n" );
        query.append( "                     ,c_document_eid                     \n" );
        query.append( "                     ,c_overview_eid                     \n" );
        query.append( "                     ,c_preparation_eid                  \n" );
        query.append( "                     ,c_preparationlist_eid              \n" );
        query.append( "                     ,c_detect_position                  \n" );
        query.append( "                     ,c_defect_weight                    \n" );
        query.append( "                     ,c_comments                         \n" );
        query.append( "                     ,c_del_yn                           \n" );
        query.append( "              )VALUES(                                   \n" );
        query.append( "                      ?                                  \n" );
        query.append( "                     ,?                                  \n" );
        query.append( "                     ,?                                  \n" );
        query.append( "                     ,?                                  \n" );
        query.append( "                     ,?                                  \n" );
        query.append( "                     ,?                                  \n" );
        query.append( "                     ,?                                  \n" );
        query.append( "                     ,?                                  \n" );
        query.append( "                     ,'N'                                \n" );
        query.append( "              )                                          \n" );

        PreparedStatement pstmt = null;
        int count = 0;
        Connection conn = null;
        conn = getConnection();
        try {
            if(logEnabled) pstmt = new LoggableStatement(conn,query.toString());
            else pstmt = conn.prepareStatement(query.toString());

            pstmt.setInt   ( 1, aesoppreparationlist.getUser_eid() );
            pstmt.setInt   ( 2, aesoppreparationlist.getDocument_eid() );
            pstmt.setInt   ( 3, aesoppreparationlist.getOverview_eid() );
            pstmt.setInt   ( 4, aesoppreparationlist.getPreparation_eid() );
            pstmt.setInt   ( 5, aesoppreparationlist.getPreparationlist_eid() );
            pstmt.setString( 6, aesoppreparationlist.getDetect_position() );
            pstmt.setString( 7, aesoppreparationlist.getDefect_weight() );
            pstmt.setString( 8, aesoppreparationlist.getComments() );

            if(logEnabled) log.warn(((LoggableStatement)pstmt).getQueryString());
            else log.warn( query.toString() );

            count = pstmt.executeUpdate();

            conn.commit();
        }
        catch (Exception e) {
            e.printStackTrace();
            try{ conn.rollback(); }catch(SQLException sqlex){sqlex.printStackTrace();}
            throw new DatabaseException();
        }
        finally {
            try {closeConnection( conn );} catch (Exception e) { /*do nothing*/}
        }
        return count;

    }

    public int selectSeq( AesoppreparationlistDTO aesoppreparationlist ) throws DatabaseException {
        int count = 0;
        StringBuffer query = new StringBuffer();
        query.append( "SELECT MAX(c_preparationlist_eid) + 1 eid           \n" );
        query.append( "  FROM TB_PREPARATIONLIST                           \n" );
        query.append( " WHERE c_document_eid = ?                           \n" );
        query.append( "   AND c_overview_eid  = ?                          \n" );
        query.append( "   AND c_user_eid = ?                               \n" );
        query.append( "   AND c_preparation_eid = ?                        \n" );

        PreparedStatement pstmt = null;
        ResultSet rs = null;
        Connection conn = null;
        conn = getConnection();

        try {
            if(logEnabled) pstmt = new LoggableStatement(conn,query.toString());
            else pstmt = conn.prepareStatement(query.toString());

            pstmt.setInt( 1, aesoppreparationlist.getDocument_eid() );
            pstmt.setInt( 2, aesoppreparationlist.getOverview_eid() );
            pstmt.setInt( 3, aesoppreparationlist.getUser_eid() );
            pstmt.setInt( 4, aesoppreparationlist.getPreparation_eid() );
            
            if(logEnabled) log.warn(((LoggableStatement)pstmt).getQueryString());
            else log.warn( query.toString() );

            rs = pstmt.executeQuery();

            if (rs.next()) {
              count= rs.getInt("eid");
            }
        }
        catch (Exception e) {
            e.printStackTrace();
            throw new DatabaseException();
        }
        finally {
            try {closeConnection( conn );} catch (Exception e) { /*do nothing*/}
        }

        return count;

    }


    public AesoppreparationlistDTO[] selectAesoppreparationlistList( AesoppreparationlistDTO aesoppreparationlist ) throws DatabaseException {
        AesoppreparationlistDTO[] arrDto = null;
        ArrayList list = new ArrayList();

        StringBuffer query = new StringBuffer();
        query.append( "SELECT                                                   \n" );
        query.append( "        a.c_user_eid             c_user_eid              \n" );
        query.append( "       ,a.c_overview_eid         c_overview_eid          \n" );
        query.append( "       ,a.c_document_eid         c_document_eid          \n" );        
        query.append( "       ,a.c_preparation_eid      c_preparation_eid       \n" );
        query.append( "       ,a.c_preparationlist_eid  c_preparationlist_eid   \n" );
        query.append( "       ,a.c_detect_position      c_detect_position       \n" );
        query.append( "       ,a.c_defect_weight        c_defect_weight         \n" );
        query.append( "       ,a.c_comments             c_comments              \n" );
        query.append( "       ,b.name                   c_defect_weight_lb      \n" );
        query.append( "  FROM TB_PREPARATIONLIST a                              \n" );
        query.append( "      ,TB_CODE b                                         \n" );
        query.append( " WHERE a.c_document_eid = ?                              \n" );
        query.append( "   AND a.c_overview_eid = ?                              \n" );
        query.append( "   AND a.c_user_eid = ?                                  \n" );
        query.append( "   AND a.c_preparation_eid = ?                           \n" );
        query.append( "   AND a.c_del_yn = 'N'                                  \n" );
        query.append( "   AND a.c_defect_weight = b.class_id                    \n" );
        query.append( "   AND b.class_group = 2104                              \n" );
        
        PreparedStatement pstmt = null;
        ResultSet rs = null;
        Connection conn = null;
        conn = getConnection();

        try {
            if(logEnabled) pstmt = new LoggableStatement(conn,query.toString());
            else pstmt = conn.prepareStatement(query.toString());

            pstmt.setInt( 1, aesoppreparationlist.getDocument_eid() );
            pstmt.setInt( 2, aesoppreparationlist.getOverview_eid() );
            pstmt.setInt( 3, aesoppreparationlist.getUser_eid() );
            pstmt.setInt( 4, aesoppreparationlist.getPreparation_eid() );
            
            if(logEnabled) log.warn(((LoggableStatement)pstmt).getQueryString());
            else log.warn( query.toString() );

            rs = pstmt.executeQuery();

            while ( rs.next() ){
                AesoppreparationlistDTO dto = new AesoppreparationlistDTO();
                dto.setUser_eid( rs.getInt( "c_user_eid" ) );
                dto.setOverview_eid( rs.getInt( "c_overview_eid" ) );
                dto.setDocument_eid( rs.getInt( "c_document_eid" ) );
                dto.setPreparation_eid( rs.getInt( "c_preparation_eid" ) );
                dto.setPreparationlist_eid( rs.getInt( "c_preparationlist_eid" ) );
                dto.setDetect_position( rs.getString( "c_detect_position" ) );
                dto.setDefect_weight( rs.getString( "c_defect_weight" ) );
                dto.setComments( rs.getString( "c_comments" ) );
                dto.setDefect_weight_lb( rs.getString( "c_defect_weight_lb" ) );
                list.add(dto);
            }
        }
        catch (Exception e) {
            e.printStackTrace();
            throw new DatabaseException();
        }
        finally {
            try {closeConnection( conn );} catch (Exception e) { /*do nothing*/}
        }

        arrDto = new AesoppreparationlistDTO[list.size()];
        list.toArray( arrDto );
        return arrDto;

    }

    public AesoppreparationlistDTO[] selectAesoppreparationalllistList( AesoppreparationlistDTO aesoppreparationlist ) throws DatabaseException {
        AesoppreparationlistDTO[] arrDto = null;
        ArrayList list = new ArrayList();

        StringBuffer query = new StringBuffer();
        query.append( "SELECT                                                   \n" );
        query.append( "        a.c_user_eid             c_user_eid              \n" );
        query.append( "       ,c.c_name                 c_user_eid_lb           \n" );
        query.append( "       ,a.c_overview_eid         c_overview_eid          \n" );
        query.append( "       ,a.c_document_eid         c_document_eid          \n" );        
        query.append( "       ,a.c_preparation_eid      c_preparation_eid       \n" );
        query.append( "       ,a.c_preparationlist_eid  c_preparationlist_eid   \n" );
        query.append( "       ,a.c_detect_position      c_detect_position       \n" );
        query.append( "       ,a.c_defect_weight        c_defect_weight         \n" );
        query.append( "       ,a.c_comments             c_comments              \n" );
        query.append( "       ,b.name                   c_defect_weight_lb      \n" );
        query.append( "  FROM TB_PREPARATIONLIST a                              \n" );
        query.append( "      ,TB_CODE b                                         \n" );
        query.append( "      ,TB_USER c                                         \n" );
        query.append( " WHERE a.c_document_eid = ?                              \n" );
        query.append( "   AND a.c_overview_eid = ?                              \n" );
        query.append( "   AND a.c_preparation_eid = ?                           \n" );
        query.append( "   AND a.c_del_yn = 'N'                                  \n" );
        query.append( "   AND a.c_defect_weight = b.class_id                    \n" );
        query.append( "   AND b.class_group = 2104                              \n" );
        query.append( "   AND a.c_user_eid = c.c_user_eid                       \n" );
        query.append( " ORDER BY a.c_user_eid                                   \n" );
        query.append( "      ,a.c_document_eid                                  \n" );
        query.append( "      ,a.c_overview_eid                                  \n" );
        query.append( "      ,a.c_preparation_eid                               \n" );
        query.append( "      ,a.c_preparationlist_eid                           \n" );
        
        PreparedStatement pstmt = null;
        ResultSet rs = null;
        Connection conn = null;
        conn = getConnection();

        try {
            if(logEnabled) pstmt = new LoggableStatement(conn,query.toString());
            else pstmt = conn.prepareStatement(query.toString());

            pstmt.setInt( 1, aesoppreparationlist.getDocument_eid() );
            pstmt.setInt( 2, aesoppreparationlist.getOverview_eid() );
            pstmt.setInt( 3, aesoppreparationlist.getPreparation_eid() );
            
            if(logEnabled) log.warn(((LoggableStatement)pstmt).getQueryString());
            else log.warn( query.toString() );

            rs = pstmt.executeQuery();

            while ( rs.next() ){
                AesoppreparationlistDTO dto = new AesoppreparationlistDTO();
                dto.setUser_eid( rs.getInt( "c_user_eid" ) );
                dto.setUser_eid_lb( rs.getString( "c_user_eid_lb" ) );
                dto.setOverview_eid( rs.getInt( "c_overview_eid" ) );
                dto.setDocument_eid( rs.getInt( "c_document_eid" ) );
                dto.setPreparation_eid( rs.getInt( "c_preparation_eid" ) );
                dto.setPreparationlist_eid( rs.getInt( "c_preparationlist_eid" ) );
                dto.setDetect_position( rs.getString( "c_detect_position" ) );
                dto.setDefect_weight( rs.getString( "c_defect_weight" ) );
                dto.setComments( rs.getString( "c_comments" ) );
                dto.setDefect_weight_lb( rs.getString( "c_defect_weight_lb" ) );
                list.add(dto);
            }
        }
        catch (Exception e) {
            e.printStackTrace();
            throw new DatabaseException();
        }
        finally {
            try {closeConnection( conn );} catch (Exception e) { /*do nothing*/}
        }

        arrDto = new AesoppreparationlistDTO[list.size()];
        list.toArray( arrDto );
        return arrDto;

    }

    public AesoppreparationlistDTO selectAesoppreparationlist( AesoppreparationlistDTO aesoppreparationlist ) throws DatabaseException {
        AesoppreparationlistDTO dto = new AesoppreparationlistDTO();

        StringBuffer query = new StringBuffer();
        query.append( "SELECT                                                   \n" );
        query.append( "        a.c_user_eid             c_user_eid              \n" );
        query.append( "       ,a.c_overview_eid         c_overview_eid          \n" );
        query.append( "       ,a.c_document_eid         c_document_eid          \n" );
        query.append( "       ,a.c_preparation_eid      c_preparation_eid       \n" );
        query.append( "       ,a.c_preparationlist_eid  c_preparationlist_eid   \n" );
        query.append( "       ,a.c_detect_position      c_detect_position       \n" );
        query.append( "       ,a.c_defect_weight        c_defect_weight         \n" );
        query.append( "       ,a.c_comments             c_comments              \n" );
        query.append( "       ,b.name                   c_defect_weight_lb      \n" );
        query.append( "  FROM TB_PREPARATIONLIST a                              \n" );
        query.append( "      ,TB_CODE b                                         \n" );
        query.append( " WHERE a.c_document_eid = ?                              \n" );
        query.append( "   AND a.c_overview_eid = ?                              \n" );
        query.append( "   AND a.c_user_eid = ?                                  \n" );
        query.append( "   AND a.c_preparation_eid = ?                           \n" );
        query.append( "   AND a.c_preparationlist_eid = ?                       \n" );
        query.append( "   AND a.c_defect_weight = b.class_id                    \n" );
        query.append( "   AND b.class_group = 2104                              \n" );
        
        PreparedStatement pstmt = null;
        ResultSet rs = null;
        Connection conn = null;
        conn = getConnection();

        try {
            if(logEnabled) pstmt = new LoggableStatement(conn,query.toString());
            else pstmt = conn.prepareStatement(query.toString());

            pstmt.setInt( 1, aesoppreparationlist.getDocument_eid() );
            pstmt.setInt( 2, aesoppreparationlist.getOverview_eid() );
            pstmt.setInt( 3, aesoppreparationlist.getUser_eid() );
            pstmt.setInt( 4, aesoppreparationlist.getPreparation_eid() );
            pstmt.setInt( 5, aesoppreparationlist.getPreparationlist_eid() );

            if(logEnabled) log.warn(((LoggableStatement)pstmt).getQueryString());
            else log.warn( query.toString() );

            rs = pstmt.executeQuery();

            if (rs.next()) {
                dto.setUser_eid( rs.getInt( "c_user_eid" ) );
                dto.setOverview_eid( rs.getInt( "c_overview_eid" ) );
                dto.setDocument_eid( rs.getInt( "c_document_eid" ) );
                dto.setPreparation_eid( rs.getInt( "c_preparation_eid" ) );
                dto.setPreparationlist_eid( rs.getInt( "c_preparationlist_eid" ) );
                dto.setDetect_position( rs.getString( "c_detect_position" ) );
                dto.setDefect_weight( rs.getString( "c_defect_weight" ) );
                dto.setComments( rs.getString( "c_comments" ) );
                dto.setDefect_weight_lb( rs.getString( "c_defect_weight_lb" ) );
            }
        }
        catch (Exception e) {
            e.printStackTrace();
            throw new DatabaseException();
        }
        finally {
            try {closeConnection( conn );} catch (Exception e) { /*do nothing*/}
        }

        return dto;

    }



    public int updateAesoppreparationlist( AesoppreparationlistDTO aesoppreparationlist ) throws DatabaseException {
        StringBuffer query = new StringBuffer();
        query.append( "UPDATE TB_PREPARATIONLIST SET                            \n" );
        query.append( "        c_detect_position = ?                            \n" );
        query.append( "       ,c_defect_weight = ?                              \n" );
        query.append( "       ,c_comments = ?                                   \n" );
        query.append( " WHERE c_document_eid = ?                                \n" );
        query.append( "   AND c_overview_eid = ?                                \n" );
        query.append( "   AND c_user_eid = ?                                    \n" );
        query.append( "   AND c_preparation_eid = ?                             \n" );
        query.append( "   AND c_preparationlist_eid = ?                         \n" );
        
        PreparedStatement pstmt = null;
        int count = 0;
        Connection conn = null;
        conn = getConnection();

        try {
            if(logEnabled) pstmt = new LoggableStatement(conn,query.toString());
            else pstmt = conn.prepareStatement(query.toString());

            pstmt.setString( 1, aesoppreparationlist.getDetect_position() );
            pstmt.setString( 2, aesoppreparationlist.getDefect_weight() );
            pstmt.setString( 3, aesoppreparationlist.getComments() );
            pstmt.setInt   ( 4, aesoppreparationlist.getDocument_eid() );
            pstmt.setInt   ( 5, aesoppreparationlist.getOverview_eid() );
            pstmt.setInt   ( 6, aesoppreparationlist.getUser_eid() );
            pstmt.setInt   ( 7, aesoppreparationlist.getPreparation_eid() );
            pstmt.setInt   ( 8, aesoppreparationlist.getPreparationlist_eid() );

            if(logEnabled) log.warn(((LoggableStatement)pstmt).getQueryString());
            else log.warn( query.toString() );

            count = pstmt.executeUpdate();

            conn.commit();
        }
        catch (Exception e) {
            e.printStackTrace();
            try{ conn.rollback(); }catch(SQLException sqlex){sqlex.printStackTrace();}
            throw new DatabaseException();
        }
        finally {
            try {closeConnection( conn );} catch (Exception e) { /*do nothing*/}
        }
        return count;

    }


    public int deleteAesoppreparationlist( AesoppreparationlistDTO aesoppreparationlist ) throws DatabaseException {
        StringBuffer query = new StringBuffer();
        query.append( "UPDATE TB_PREPARATIONLIST                                \n" );
        query.append( "   SET c_del_yn = 'Y'                                    \n" );
        query.append( " WHERE c_document_eid = ?                                \n" );
        query.append( "   AND c_overview_eid = ?                                \n" );
        query.append( "   AND c_user_eid = ?                                    \n" );
        query.append( "   AND c_preparation_eid = ?                             \n" );
        query.append( "   AND c_preparationlist_eid = ?                         \n" );
        
        PreparedStatement pstmt = null;
        int count = 0;
        Connection conn = null;
        conn = getConnection();

        try {
            if(logEnabled) pstmt = new LoggableStatement(conn,query.toString());
            else pstmt = conn.prepareStatement(query.toString());

            pstmt.setInt( 1, aesoppreparationlist.getDocument_eid() );
            pstmt.setInt( 2, aesoppreparationlist.getOverview_eid() );
            pstmt.setInt( 3, aesoppreparationlist.getUser_eid() );
            pstmt.setInt( 4, aesoppreparationlist.getPreparation_eid() );
            pstmt.setInt( 5, aesoppreparationlist.getPreparationlist_eid() );

            if(logEnabled) log.warn(((LoggableStatement)pstmt).getQueryString());
            else log.warn( query.toString() );

            count = pstmt.executeUpdate();

            conn.commit();
        }
        catch (Exception e) {
            e.printStackTrace();
            try{ conn.rollback(); }catch(SQLException sqlex){sqlex.printStackTrace();}
            throw new DatabaseException();
        }
        finally {
            try {closeConnection( conn );} catch (Exception e) { /*do nothing*/}
        }
        return count;

    }

}
